@@ -1,6 +1,6 @@
 package Statocles::App::Blog;
 # ABSTRACT: A blog application
-$Statocles::App::Blog::VERSION = '0.044';
+$Statocles::App::Blog::VERSION = '0.045';
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store::File;
@@ -158,6 +158,25 @@ sub post_pages {
     return @pages;
 }
 
+
+sub post_files {
+    my ( $self ) = @_;
+    my @pages;
+
+    my $iter = $self->store->find_files;
+    while ( my $path = $iter->() ) {
+        next unless $path =~ m{^/(\d{4})/(\d{2})/(\d{2})/[^/]+/};
+        next if $path =~ /[.]markdown$/;
+
+        push @pages, Statocles::Page::File->new(
+            path => $path,
+            fh => $self->store->open_file( $path ),
+        );
+    }
+
+    return @pages;
+}
+
 # Return the post docs sorted by date, pruning any docs that are after
 # the current date
 sub _sorted_docs {
@@ -335,6 +354,7 @@ sub pages {
     my @post_pages = $self->post_pages;
     return (
         ( map { $self->$_( @post_pages ) } qw( index tag_pages ) ),
+        $self->post_files,
         @post_pages,
     );
 }
@@ -366,15 +386,23 @@ sub _tag_url {
 
 
 sub recent_posts {
-    my ( $self, $count ) = @_;
+    my ( $self, $count, %filter ) = @_;
 
     my $today = Time::Piece->new->ymd;
     my @pages;
     my @docs = $self->_sorted_docs;
-    for my $doc ( @docs[0..$count-1] ) {
+    DOC: for my $doc ( @docs ) {
+        QUERY: for my $attr ( keys %filter ) {
+            my $value = $filter{ $attr };
+            if ( $attr eq 'tags' ) {
+                next DOC unless grep { $_ eq $value } @{ $doc->tags };
+            }
+        }
+
         my $page = $self->_make_post_page( $doc );
         $page->path( join "/", $self->url_root, $page->path );
         push @pages, $page;
+        last if @pages >= $count;
     }
 
     return @pages;
@@ -404,7 +432,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 DESCRIPTION
 
@@ -485,6 +513,10 @@ Given a post title, remove special characters to create a slug.
 
 Get the individual post Statocles::Page objects.
 
+=head2 post_files()
+
+Get all the post collateral files.
+
 =head2 index()
 
 Get the index page (a L<list page|Statocles::Page::List>) for this application.
@@ -506,11 +538,16 @@ tag links. The common attributes are:
     text => 'The tag text'
     href => 'The URL to the tag page'
 
-=head2 recent_posts( $count )
+=head2 recent_posts( $count, %filter )
 
 Get the last $count recent posts for this blog. Useful for templates and site
 index pages.
 
+%filter is an optional set of filters to apply to only show recent posts
+matching the given criteria. The following filters are available:
+
+    tags        -> (string) Only show posts with the given tag
+
 =head2 page_url( page )
 
 Return the absolute URL to this page, removing the "/index.html" if necessary.
