@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.044';
+$Statocles::Command::VERSION = '0.045';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through bundling no_auto_abbrev );
@@ -27,6 +27,7 @@ sub main {
         verbose => 0,
     );
     GetOptionsFromArray( \@argv, \%opt,
+        'port|p=i',
         'config:s',
         'site:s',
         'help|h',
@@ -104,6 +105,10 @@ sub main {
             ),
         );
 
+        if ( $opt{port} ) {
+            $daemon->listen([ "http://*:$opt{port}" ]);
+        }
+
         # Using start() instead of run() so we can stop() inside the tests
         $daemon->start;
 
@@ -461,7 +466,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 SYNOPSIS
 
