@@ -1,8 +1,9 @@
 package Statocles::Plugin::LinkCheck;
 # ABSTRACT: Check links and images for validity during build
-$Statocles::Plugin::LinkCheck::VERSION = '0.044';
+$Statocles::Plugin::LinkCheck::VERSION = '0.045';
 use Statocles::Base 'Class';
 use Mojo::DOM;
+use Mojo::Util qw( url_escape url_unescape );
 
 
 has ignore => (
@@ -31,7 +32,7 @@ sub check_pages {
                     if ( $url !~ m{^/} ) {
                         $url = $page->path->parent->child( $url );
                     }
-                    $links{ $url }{ $page->path }++;
+                    $links{ url_unescape $url }{ $page->path }++;
 
                 }
             }
@@ -61,7 +62,7 @@ Statocles::Plugin::LinkCheck - Check links and images for validity during build
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 SYNOPSIS
 
